package vn.lecle.lecle_screen_manager

import android.app.Activity
import android.content.Context
import android.provider.Settings
import android.view.WindowManager
import androidx.annotation.NonNull
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result


/** LecleScreenManagerPlugin */
class LecleScreenManagerPlugin : FlutterPlugin, MethodCallHandler, ActivityAware {
    /// The MethodChannel that will the communication between Flutter and native Android
    ///
    /// This local reference serves to register the plugin with the Flutter Engine and unregister it
    /// when the Flutter Engine is detached from the Activity
    private lateinit var channel: MethodChannel
    private lateinit var activity: Activity
    private lateinit var context: Context

    override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
        channel = MethodChannel(flutterPluginBinding.binaryMessenger, "lecle_screen_manager")
        channel.setMethodCallHandler(this)
        context = flutterPluginBinding.applicationContext
    }

    override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
        when (call.method) {
            "brightness" -> result.success(getBrightness())
            "setBrightness" -> {
                val brightness: Double = call.argument<Double>("brightness")!!
                val layoutParams: WindowManager.LayoutParams = activity.window.attributes
                layoutParams.screenBrightness = brightness.toFloat()
                activity.window.attributes = layoutParams
                result.success(null)
            }
            "isKeptOn" -> {
                val flags: Int = activity.window.attributes.flags
                result.success(flags and WindowManager.LayoutParams.FLAG_KEEP_SCREEN_ON != 0)
            }
            "keepOn" -> {
                val on: Boolean = call.argument<Boolean>("on")!!
                if (on) {
                    println("Keeping screen on ")
                    activity.window.addFlags(WindowManager.LayoutParams.FLAG_KEEP_SCREEN_ON)
                } else {
                    println("Not keeping screen on")
                    activity.window.clearFlags(WindowManager.LayoutParams.FLAG_KEEP_SCREEN_ON)
                }
                result.success(null)
            }
            else -> result.notImplemented()
        }
    }

    override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
        channel.setMethodCallHandler(null)
    }

    private fun getBrightness(): Float {
        var result: Float = activity.window.attributes.screenBrightness
        if (result < 0) { // the application is using the system brightness
            try {
                result = Settings.System.getInt(context.contentResolver, Settings.System.SCREEN_BRIGHTNESS) / 255.toFloat()
            } catch (e: Settings.SettingNotFoundException) {
                result = 1.0f
                e.printStackTrace()
            }
        }
        return result
    }

    override fun onAttachedToActivity(binding: ActivityPluginBinding) {
        activity = binding.activity
    }

    override fun onDetachedFromActivityForConfigChanges() {
    }

    override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {
    }

    override fun onDetachedFromActivity() {
    }
}
