import 'dart:async';

import 'package:flutter/services.dart';

/// Simple class to call for invoking the method that get and set the brightness and keep screen on in Android and iOS device
class LecleScreenManager {
  /// Invoke method channel to get and set the brightness and keep screen on in Android and iOS device
  static const MethodChannel _channel = MethodChannel('lecle_screen_manager');

  /// Static property to get the screen current brightness
  static Future<double> get brightness async =>
      (await _channel.invokeMethod('brightness')) as double;

  /// Static method to set the screen brightness
  static Future<void> setBrightness(double brightness) =>
      _channel.invokeMethod('setBrightness', {"brightness": brightness});

  /// Static property to get is the screen is keeping on or not
  static Future<bool> get isKeptOn async =>
      (await _channel.invokeMethod('isKeptOn')) as bool;

  /// Static method to set the screen keeping on or not
  static Future<void> keepOn(bool on) =>
      _channel.invokeMethod('keepOn', {"on": on});
}
